package ext.chart.series.sprite {

[Native("Ext.chart.series.sprite.Line", require)]
/**
 * Line series sprite.
 * @see https://docs.sencha.com/extjs/7.2.0/classic/Ext.chart.series.sprite.Line.html Original Ext JS documentation of 'Ext.chart.series.sprite.Line'
 */
public class LineSeriesSprite extends ext.chart.series.sprite.AggregativeSeriesSprite {
  /**
   * @inheritDoc
   */
  public function LineSeriesSprite(config:ext.chart.series.sprite.LineSeriesSprite = null) {
    super();
  }

  [ExtConfig]
  /**
   * The type of curve that connects the data points.
   * <p>For example:</p>
   * <pre>
   * // The data points are connected by line segments.
   * // This is the default setting.
   * curve: {
   *     type: 'linear'
   * }
   *
   * // Cardinal spline interpolation is used to produce the curve
   * // that connects the data points. The `tension` parameter can
   * // be used to control the smoothness of the curve. A tension
   * // of 0 corresponds to infinite tension, which results in straight
   * // lines between data points. A tension of 1 corresponds to
   * // no tension, allowing the spline to take the path of least
   * // total bend. With tension values greater than 1, the curve
   * // behaves like a compressed spring, pushed to take a longer path.
   * // A cardinal spline with a tension of 0.5 is a special case.
   * // It is then called a Catmull-Rom spline. Catmull-Rom splines are
   * // thought to be esthetically pleasing and are quite common.
   * // Note: spline interpolation only works on gapless data.
   * curve: {
   *     type: 'cardinal,
   *     tension: 0.5
   * }
   *
   * // Produces a natural cubic spline with the second derivative
   * // of the spline set to zero at the endpoints.
   * curve: {
   *     type: 'natural'
   * }
   *
   * // The data points are connected by alternating horizontal and
   * // vertical lines. The y-value changes after the x-value.
   * curve: {
   *     type: 'step-after'
   * }
   * </pre>
   * @default {type: 'linear'}
   * @see https://docs.sencha.com/extjs/7.2.0/classic/Ext.chart.series.sprite.Line.html#cfg-curve Original Ext JS documentation of 'curve'
   */
  public native function get curve():Object;

  [ExtConfig]
  /**
   * @private
   */
  public native function set curve(value:Object):void;

  [ExtConfig]
  /**
   * <code>true</code> if the sprite paints the area underneath the line.
   * @default false
   * @see https://docs.sencha.com/extjs/7.2.0/classic/Ext.chart.series.sprite.Line.html#cfg-fillArea Original Ext JS documentation of 'fillArea'
   */
  public native function get fillArea():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set fillArea(value:Boolean):void;

  [ExtConfig]
  /**
   * Possible values:
   * 'gap' - null points are rendered as gaps.
   * 'connect' - non-null points are connected across null points, so that
   * there is no gap, unless null points are at the beginning/end of the line.
   * Only the visible data points are connected - if a visible data point
   * is followed by a series of null points that go off screen and eventually
   * terminate with a non-null point, the connection won't be made.
   * 'origin' - null data points are rendered at the origin,
   * which is the y-coordinate of a point where the x and y axes meet.
   * This requires that at least the x-coordinate of a point is a valid value.
   * @default "gap"
   * @see https://docs.sencha.com/extjs/7.2.0/classic/Ext.chart.series.sprite.Line.html#cfg-nullStyle Original Ext JS documentation of 'nullStyle'
   */
  public native function get nullStyle():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set nullStyle(value:String):void;

  [ExtConfig]
  /**
   * <code>true</code> if the line uses precise stroke.
   * @default true
   * @see https://docs.sencha.com/extjs/7.2.0/classic/Ext.chart.series.sprite.Line.html#cfg-preciseStroke Original Ext JS documentation of 'preciseStroke'
   */
  public native function get preciseStroke():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set preciseStroke(value:Boolean):void;

  [ExtConfig]
  /**
   * Absolute maximum y-value.
   * Larger values will be capped to avoid rendering issues.
   * @default Math.pow(2, 20)
   * @see https://docs.sencha.com/extjs/7.2.0/classic/Ext.chart.series.sprite.Line.html#cfg-yCap Original Ext JS documentation of 'yCap'
   */
  public native function get yCap():Number;

  [ExtConfig]
  /**
   * @private
   */
  public native function set yCap(value:Number):void;
}
}