package ext.form.action {

[Native("Ext.form.action.DirectLoad", require)]
/**
 * Provides Ext Direct support for loading form data.
 * <p>This example illustrates usage of Ext Direct to load a form.</p>
 * <pre>
 * var myFormPanel = new Ext.form.Panel({
 *     // configs for FormPanel
 *     title: 'Basic Information',
 *     renderTo: document.body,
 *     width: 300, height: 160,
 *     padding: 10,
 *
 *     // configs apply to child items
 *     defaults: {anchor: '100%'},
 *     defaultType: 'textfield',
 *     items: [{
 *         fieldLabel: 'Name',
 *         name: 'name'
 *     },{
 *         fieldLabel: 'Email',
 *         name: 'email'
 *     },{
 *         fieldLabel: 'Company',
 *         name: 'company'
 *     }],
 *
 *     // configs for BasicForm
 *     api: {
 *         // The server-side method to call for load() requests
 *         load: 'Profile.getBasicInfo',
 *         // The server-side must mark the submit handler as a 'formHandler'
 *         submit: 'Profile.updateBasicInfo'
 *     },
 *     // specify the order for the passed params
 *     paramOrder: ['uid', 'foo']
 * });
 *
 * // load the form
 * myFormPanel.getForm().load({
 *     // pass 2 arguments to server side getBasicInfo method (len=2)
 *     params: {
 *         foo: 'bar',
 *         uid: 34
 *     }
 * });
 * </pre>
 * <p>Before using DirectLoad action, make sure you set up Ext Direct remoting provider.
 * See →<code>ext.direct.DirectManager</code> for more information.</p>
 * <p>For corresponding submit action, see →<code>ext.form.action.DirectSubmitAction</code>.</p>
 * @see ext.direct.#DirectManager ext.direct.DirectManager
 * @see ext.form.action.DirectSubmitAction
 * @see https://docs.sencha.com/extjs/7.2.0/classic/Ext.form.action.DirectLoad.html Original Ext JS documentation of 'Ext.form.action.DirectLoad'
 */
public class DirectLoadAction extends ext.form.action.LoadAction implements ext.form.action.IDirectAction {
  /**
   * @param config @inheritDoc
   */
  public function DirectLoadAction(config:ext.form.action.DirectLoadAction = null) {
    super();
  }
}
}